// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-drafts
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/

var ApicCliUtil = require('apiconnect-cli-util');
var requestDefaultOptions = ApicCliUtil.Util.requestDefaultOptions;
var request = ApicCliUtil.Request;
var ServerError = ApicCliUtil.ServerError;

function Factory() {}

Factory.prototype.createCatalog = function(displayName, options, callback) {
  var opts = requestDefaultOptions();
  opts.url += catalogCreateUrl(options.organization);

  opts.headers['content-type'] = 'application/json';
  opts.json = { name: displayName, shortName: options.name };

  request.post(opts, function(err, rsp, body) {
    if (err) {
      return callback(err);
    } else if (rsp.statusCode === 201) {
      return callback(null, body);
    } else {
      return callback(new ServerError(rsp.statusCode, body));
    }
  });
};

Factory.prototype.getCatalog = function(catalogName, options, callback) {
  var opts = requestDefaultOptions();
  opts.url += catalogGetUrl(options.organization, catalogName);

  request.get(opts, function(err, rsp, body) {
    if (err) {
      return callback(err);
    } else if (rsp.statusCode === 200) {
      var result = JSON.parse(body);

      return callback(null, result);
    } else {
      return callback(new ServerError(rsp.statusCode, body));
    }
  });
};

Factory.prototype.deleteCatalog = function(catalogName, options, callback) {
  var opts = requestDefaultOptions();
  opts.url += catalogDeleteUrl(options.organization, catalogName);
  opts.headers['content-type'] = 'application/json';

  request.del(opts, function(err, rsp, body) {
    if (err) {
      return callback(err);
    } else if (rsp.statusCode === 204) {
      return callback(null);
    } else {
      return callback(new ServerError(rsp.statusCode, body));
    }
  });
};

var catalogCreateUrl = function(orgName) {
  return '/v1/orgs/' + orgName + '/environments/';
};

var catalogGetUrl = function(orgName, catalogName) {
  return '/v1/orgs/' + orgName + '/environments/' + catalogName;
};

var catalogDeleteUrl = function(orgName, catalogName) {
  return '/v1/orgs/' + orgName + '/environments/' + catalogName;
};

module.exports = Factory;
