// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-catalogs
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/
/*eslint brace-style: 0, max-len: 0*/

var fs = require('fs');
var path = require('path');

function helpInfo(helpFile) {
  return fs.readFileSync(path.join(__dirname, '..', 'intl', 'en', helpFile),
    'utf-8');
}

module.exports = {
  name: 'catalogs',
  version: require('../package.json').version,
  path: __filename,
  isBuiltin: true,
  topics: getTopics,
};

function getTopics() {
  return [ {
    name: 'catalogs',
    commands: [
      {
        command: 'list',
        loginRequired: 'org',
        aliases: [ 'catalogs' ],
        helpInfo: function() {
          return helpInfo('apic_catalogs_list_help.txt');
        },
        action: function(opts) {
          return require('./plugin-impl').catalogsList(opts);
        },
        options: [
          { name: 'all-organizations', rune: 'O', type: 'boolean' },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs' },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'create <displayName>',
        loginRequired: 'org',
        helpInfo: function() {
          return helpInfo('apic_catalogs_create_help.txt');
        },
        action: function(displayName, opts) {
          return require('./plugin-impl').catalogsCreate(displayName, opts);
        },
        options: [
          { name: 'name' },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'get <name>',
        loginRequired: 'org',
        helpInfo: function() {
          return helpInfo('apic_catalogs_get_help.txt');
        },
        action: function(name, opts) {
          return require('./plugin-impl').catalogsGet(name, opts);
        },
        options: [
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'delete <name>',
        loginRequired: 'org',
        helpInfo: function() {
          return helpInfo('apic_catalogs_delete_help.txt');
        },
        action: function(name, opts) {
          return require('./plugin-impl').catalogsDelete(name, opts);
        },
        options: [
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
    ],
  } ];
}
