#!/usr/bin/env node
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-catalogs
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/

var ApicCliUtil = require('apiconnect-cli-util');
var apicUtil = ApicCliUtil.Util;
var Formatter = require('./formatter');
var Factory = require('./factory');
var Promise = require('bluebird');

var Catalogs = ApicCliUtil.Catalogs;
var context = ApicCliUtil.Context;

Promise.promisifyAll(Factory.prototype);

module.exports.catalogsList = catalogsList;
function catalogsList(options) {
  var fmt = new Formatter();

  if (options.allOrganizations) {
    options.organization = null;
  } else if (!options.organization) {
    throw new Error('The --organization option is required');
  }

  if (options.server) {
    context.set({ server: options.server });
  }
  if (options.organization) {
    context.set({ organization: options.organization });
  }

  var orgOptions = {
    allOrganizations: options.allOrganizations,
    organization: options.organization,
    allCatalogs: true,
    server: options.server,
  };
  var catalogs = new Catalogs();

  context.set(orgOptions);
  var list = Promise.promisify(catalogs.list);

  return list.call(catalogs)
    .then(function(res) {
      var response = catalogs.filter(orgOptions);
      fmt.listFormatter(response, orgOptions);
    })
    .catch(function(err) {
      fmt.error(err);
    });
};

module.exports.catalogsCreate = catalogsCreate;
function catalogsCreate(displayName, options) {
  var f = new Factory();
  var fmt = new Formatter();

  if (typeof options.name === 'function') {
    options.name = null;
  }
  options.name = options.name || apicUtil.generateSlugFromText(displayName);

  return f.createCatalogAsync(displayName, options).then(function(result) {
    fmt.createFormatter(result, options);
  });
}

module.exports.catalogsGet = catalogsGet;
function catalogsGet(name, options) {
  var f = new Factory();
  var fmt = new Formatter();

  return f.getCatalogAsync(name, options).then(function(result) {
    fmt.getFormatter(result, options);
  });
}

module.exports.catalogsDelete = catalogsDelete;
function catalogsDelete(name, options) {
  var f = new Factory();
  var fmt = new Formatter();

  return f.deleteCatalogAsync(name, options).then(function(result) {
    fmt.deleteFormatter(name, options);
  });
}
